==> whombat-0.4.1.tar.gz: whombat-0.4.1/CONTRIBUTING.md <==
# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit
helps, and credit will always be given.

You can contribute in many ways:

## Types of Contributions

### Report Bugs

Report bugs at <https://github.com/mbsantiago/whombat/issues>.

If you are reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" and "help
wanted" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation

Whombat could always use more documentation, whether as part of the official
Whombat docs, in docstrings, or even on the web in blog posts, articles, and
such.

### Submit Feedback

The best way to send feedback is to file an issue at
<https://github.com/mbsantiago/whombat/issues>.

If you are proposing a feature:

- Explain in detail how it would work.
- Keep the scope as narrow as possible, to make it easier to implement.
- Remember that this is a volunteer-driven project, and that contributions are
  welcome :)

## Get Started

Ready to contribute? Here's how to set up `whombat` for local development.

1. Fork the `whombat` repo on GitHub.
2. Clone your fork locally

       ```{bash}
       git clone git@github.com:your_name_here/whombat.git
       ```

3. We recommend the use of [pdm](https://pdm-project.org/latest/) to manage the
   dev environment. Once pdm is installed

       ```{bash}
       pdm install
       ```

4. Create a branch for local development

       ```{bash}
       git checkout -b name-of-your-bugfix-or-feature
       ```

   Now you can make your changes locally.

5. When you're done making changes, check that your changes pass all lints and
   tests.

       ```{bash}
       pdm run make test
       pdm run make lint
       ```

6. Commit your changes and push your branch to GitHub

       ```{bash}
       git add .
       git commit -m "Your detailed description of your changes."
       git push origin name-of-your-bugfix-or-feature
       ```

7. Submit a pull request through the GitHub website.

## Pull Request Guidelines

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include tests.
2. If the pull request adds functionality, the docs should be updated. Put your
   new functionality into a function with a docstring, and add the feature to
   the list in README.rst.
3. The pull request should work for Python 3.11.

## Tips

To run a subset of tests

```{bash}
pdm run pytest tests.test_api
```

==> whombat-0.5.0.tar.gz: whombat-0.5.0/CONTRIBUTING.md <==
# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit
helps, and credit will always be given.

You can contribute in many ways:

## Types of Contributions

### Report Bugs

Report bugs at <https://github.com/mbsantiago/whombat/issues>.

If you are reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" and "help
wanted" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation

Whombat could always use more documentation, whether as part of the official
Whombat docs, in docstrings, or even on the web in blog posts, articles, and
such.

### Submit Feedback

The best way to send feedback is to file an issue at
<https://github.com/mbsantiago/whombat/issues>.

If you are proposing a feature:

- Explain in detail how it would work.
- Keep the scope as narrow as possible, to make it easier to implement.
- Remember that this is a volunteer-driven project, and that contributions are
  welcome :)

## Get Started

Ready to contribute? Here's how to set up `whombat` for local development.

1. Fork the `whombat` repo on GitHub.
2. Clone your fork locally

       ```{bash}
       git clone git@github.com:your_name_here/whombat.git
       ```

3. We recommend the use of [rye](https://rye-up.com/) to manage the
   dev environment. Once rye is installed

       ```{bash}
       rye sync
       ```

4. Create a branch for local development

       ```{bash}
       git checkout -b name-of-your-bugfix-or-feature
       ```

   Now you can make your changes locally.

5. When you're done making changes, check that your changes pass all lints and
   tests.

       ```{bash}
       make test
       make lint
       ```

6. Commit your changes and push your branch to GitHub

       ```{bash}
       git add .
       git commit -m "Your detailed description of your changes."
       git push origin name-of-your-bugfix-or-feature
       ```

7. Submit a pull request through the GitHub website.

## Pull Request Guidelines

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include tests.
2. If the pull request adds functionality, the docs should be updated. Put your
   new functionality into a function with a docstring, and add the feature to
   the list in README.rst.
3. The pull request should work for Python 3.11.

## Tips

To run a subset of tests

```{bash}
rye run pytest tests.test_api
```
